@@ -5,8 +5,14 @@ yaiVarImp = function(object, nTop=20, plot=TRUE, ...)
 {
    if (class(object) != "yai") stop ("arg must be of class yai")
    if (object$method != "randomForest") stop ("method must be randomForest")
-   if (!require (randomForest)) stop("install randomForest and try again")
-   scaledImportance = matrix(NA, nrow = length(names(object$ranForest)), ncol=length(xvars(object)))
+   if (!require (randomForest)) 
+   {
+     stop("install randomForest and try again")
+     # the purpose of this line of code is to suppress CRAN check notes
+     importance <- function (...) NULL
+   }
+   scaledImportance = matrix(NA, nrow = length(names(object$ranForest)), 
+      ncol=length(xvars(object)))
    colnames(scaledImportance) = xvars(object)
    rownames(scaledImportance) = names(object$ranForest)
 
@@ -25,13 +31,15 @@ yaiVarImp = function(object, nTop=20, plot=TRUE, ...)
    if (is.na(nTop) | nTop == 0) nTop=ncol(scaledImportance)
    scaledImportance = data.frame(scaledImportance)
    nTop = min(ncol(scaledImportance), nTop)
-   best = sort(apply(scaledImportance, 2, median, na.rm=TRUE), decreasing = TRUE, index.return = TRUE)$ix[1:nTop]
+   best = sort(apply(scaledImportance, 2, median, na.rm=TRUE), 
+               decreasing = TRUE, index.return = TRUE)$ix[1:nTop]
    if (plot)
    {
       plt = par()$plt
       oldplt = plt
       plt[1] = .2
-      boxplot(as.data.frame(scaledImportance[,best,drop=FALSE]), horizontal=TRUE, par(plt=plt), las=1,
+      boxplot(as.data.frame(scaledImportance[,best,drop=FALSE]), 
+              horizontal=TRUE, par(plt=plt), las=1,
               main=deparse(substitute(object)), xlab="Scaled Importance",...)
       par(plt=oldplt)
       invisible(scaledImportance[,best,FALSE])
